FSDNOEL : juste un sapin qui clignotte quand detection de mouvement
========================================================================

	Hardware :
		- Raspberry Pi (ou pcduino)
		- IR motion sensor as HCSR5001
		- 10A relay
		- 433 Mhz transmitter
	
	Software :
		- bibliotheque FGPIO pour gestion de tout le matériel ci-dessus
		- bibliotheque FUTIL pour débogage
		- python
		

Installation :
     pip install FSDNOEL
	 
	 

